$def with (auths)
$ most_recent = auths[0]
$var title: $most_recent["client_name"]

<h1>$most_recent["client_name"]</h1>
<p>$most_recent["client_id"]</p>

$ prev = {"redirect_uri": None}
$for auth in auths:
    $if prev["redirect_uri"] != auth["redirect_uri"]:
        <p><strong>$auth["redirect_uri"]</strong></p>
    <pre>$pformat(auth["response"])</pre>
    $ prev = auth
